@@ -127,7 +127,6 @@ class __Actions(QObject):
         self.shortFindPrevious = QShortcut(short("Find-previous"), self.ide)
         self.shortFindReplace = QShortcut(short("Find-replace"), self.ide)
         self.shortFindWithWord = QShortcut(short("Find-with-word"), self.ide)
-        self.shortHelp = QShortcut(short("Help"), self.ide)
         self.shortSplitHorizontal = QShortcut(short("Split-horizontal"),
             self.ide)
         self.shortSplitVertical = QShortcut(short("Split-vertical"), self.ide)
@@ -236,8 +235,6 @@ class __Actions(QObject):
             self.editor_comment)
         self.connect(self.shortUncomment, SIGNAL("activated()"),
             self.editor_uncomment)
-        self.connect(self.shortHelp, SIGNAL("activated()"),
-            self.ide.mainContainer.show_python_doc)
         self.connect(self.shortImport, SIGNAL("activated()"),
             self.import_from_everywhere)
         self.connect(self.shortFindInFiles, SIGNAL("activated()"),
@@ -349,7 +346,6 @@ class __Actions(QObject):
         self.shortFindPrevious.setKey(short("Find-previous"))
         self.shortFindReplace.setKey(short("Find-replace"))
         self.shortFindWithWord.setKey(short("Find-with-word"))
-        self.shortHelp.setKey(short("Help"))
         self.shortSplitHorizontal.setKey(short("Split-horizontal"))
         self.shortSplitVertical.setKey(short("Split-vertical"))
         self.shortFollowMode.setKey(short("Follow-mode"))
@@ -591,8 +587,6 @@ class __Actions(QObject):
             #TODO: Remove the IF statment with polymorphism using Handler
             if ext == 'py':
                 self.ide.misc.run_application(editorWidget.ID)
-            elif ext == 'html':
-                self.ide.misc.render_web_page(editorWidget.ID)
 
     def execute_project(self):
         """Execute the project marked as Main Project."""
